@@ -17,26 +17,17 @@
 # along with SpectralToolbox.  If not, see <http://www.gnu.org/licenses/>.
 #
 # DTU UQ Library
-# Copyright (C) 2014 The Technical University of Denmark
+# Copyright (C) 2012-2015 The Technical University of Denmark
 # Scientific Computing Section
 # Department of Applied Mathematics and Computer Science
 #
+# Copyright (C) 2015-2016 Massachusetts Institute of Technology
+# Uncertainty Quantification group
+# Department of Aeronautics and Astronautics
+#
 # Author: Daniele Bigoni
 #
 
-"""
-=========================================
- Miscellaneous
-=========================================
-
-Created on Wed Feb 27
-
-@author: Daniele Bigoni (dabi@dtu.dk)
-
-Collection of miscellaneous functions used in the SpectralToolbox
-
-"""
-
 __revision__ = filter(str.isdigit, "$Revision: 101 $")
 
 __author__ = "Daniele Bigoni"
@@ -211,7 +202,7 @@ def almostEqualList(xArray,y,tol):
         #     out[i] = (almostEqual(xArray[i,:],y,tol))
         return out
     else:
-        print "Dimension error!"
+        print("Dimension error!")
         return
 
 def binary_search(X, val, lo, hi, tol, perm=None):
@@ -530,14 +521,14 @@ class ExpandingArray:
             
         """
         if axis > len(self.__DIMS):
-            print "Error: axis number exceed the number of dimensions"
+            print("Error: axis number exceed the number of dimensions")
             return
         
         ''' Check dimensions for remaining axis '''
         for i in range(len(self.__DIMS)):
             if i != axis:
                 if X.shape[i] != self.shape()[i]:
-                    print "Error: Dimensions of the input array are not consistent in the axis %d" % i
+                    print("Error: Dimensions of the input array are not consistent in the axis %d" % i)
                     return
         
         ''' Check whether allocated memory is enough '''
